@@ -1,4 +1,4 @@
-##=============================================================================
+## =============================================================================
 
 ##' @title Change format of CATA datasets to perform the package functions
 ##'
@@ -46,46 +46,38 @@
 ##' @export
 
 
-change_cata_format2=function(Data, nprod, nattr, nsub, nsess)
-{
-  Matjuge=list()
-  Datafinal=NULL
-  if (nsess==1)
-  {
-    Data=cbind(rep(1, nrow(Data)), Data)
+change_cata_format2 <- function(Data, nprod, nattr, nsub, nsess) {
+  Matjuge <- list()
+  Datafinal <- NULL
+  if (nsess == 1) {
+    Data <- cbind(rep(1, nrow(Data)), Data)
   }
-  Data=as.data.frame(Data)
-  Data[,1]=as.factor(Data[,1])
-  Data[,2]=as.factor(Data[,2])
-  Data[,3]=as.factor(Data[,3])
+  Data <- as.data.frame(Data)
+  Data[, 1] <- as.factor(Data[, 1])
+  Data[, 2] <- as.factor(Data[, 2])
+  Data[, 3] <- as.factor(Data[, 3])
 
-  if(ncol(Data)!=nattr+3)
-  {
+  if (ncol(Data) != nattr + 3) {
     stop("The number of columns in the Data must be nattr+3 (or nattr+2 if you don't have sessions)")
   }
 
-  sessions=levels(Data[,1])
-  if(nlevels(Data[,1])!=nsess)
-  {
+  sessions <- levels(Data[, 1])
+  if (nlevels(Data[, 1]) != nsess) {
     stop("The number of sessions is not equivalent to the number of levels in first column of Data")
   }
-  subjects=levels(Data[,2])
-  if(nlevels(Data[,2])!=nsub)
-  {
-    if (nsess==1)
-    {
+  subjects <- levels(Data[, 2])
+  if (nlevels(Data[, 2]) != nsub) {
+    if (nsess == 1) {
       stop("The number of subjects is not equivalent to the number of levels in first column of Data")
-    }else{
+    } else {
       stop("The number of subjects is not equivalent to the number of levels in second column of Data")
     }
   }
   # products=levels(Data[,3])
-  if(nlevels(Data[,3])!=nprod)
-  {
-    if (nsess==1)
-    {
+  if (nlevels(Data[, 3]) != nprod) {
+    if (nsess == 1) {
       stop("The number of products is not equivalent to the number of levels in second column of Data")
-    }else{
+    } else {
       stop("The number of products is not equivalent to the number of levels in third column of Data")
     }
   }
@@ -93,30 +85,26 @@ change_cata_format2=function(Data, nprod, nattr, nsub, nsess)
 
   for (i in 1:nsub)
   {
-    Matjuge[[i]]=matrix(0, nprod, nattr)
-    Datajuge=Data[Data[,2]==subjects[i],]
-    cptsess=0
+    Matjuge[[i]] <- matrix(0, nprod, nattr)
+    Datajuge <- Data[Data[, 2] == subjects[i], ]
+    cptsess <- 0
     for (s in 1:nsess)
     {
-      Datajugerep=Datajuge[Datajuge[,1]==sessions[s],]
-      Datajugerep=Datajugerep[order(Datajugerep[,3]),]
-      Datajugerep=as.data.frame((Datajugerep[,-c(1:3)]))
-      if (nrow(Datajugerep)==nprod)
-      {
-        Matjuge[[i]]=Matjuge[[i]]+Datajugerep
-        cptsess=cptsess+1
+      Datajugerep <- Datajuge[Datajuge[, 1] == sessions[s], ]
+      Datajugerep <- Datajugerep[order(Datajugerep[, 3]), ]
+      Datajugerep <- as.data.frame((Datajugerep[, -c(1:3)]))
+      if (nrow(Datajugerep) == nprod) {
+        Matjuge[[i]] <- Matjuge[[i]] + Datajugerep
+        cptsess <- cptsess + 1
       }
     }
-    Matjuge[[i]]=Matjuge[[i]]/cptsess
-    if( i==1)
-    {
-      Datafinal=Matjuge[[i]]
-    }else
-    {
-      Datafinal=cbind(Datafinal, Matjuge[[i]])
+    Matjuge[[i]] <- Matjuge[[i]] / cptsess
+    if (i == 1) {
+      Datafinal <- Matjuge[[i]]
+    } else {
+      Datafinal <- cbind(Datafinal, Matjuge[[i]])
     }
-
   }
-  rownames(Datafinal)=unique(Datajuge[,3][order(Datajuge[,3])])
-  return(list(Datafinal=Datafinal, NameSub=subjects))
+  rownames(Datafinal) <- unique(Datajuge[, 3][order(Datajuge[, 3])])
+  return(list(Datafinal = Datafinal, NameSub = subjects))
 }
