@@ -1,10 +1,10 @@
-##=============================================================================
+## =============================================================================
 
 
-##' @title Compute the CLUSTATIS partitionning algorithm on free sorting data
+##' @title Compute the CLUSTATIS partitioning algorithm on free sorting data
 ##'
 ##' @description
-##' Partitionning algorithm for Free Sorting data. Each cluster is associated with a compromise
+##' partitioning algorithm for Free Sorting data. Each cluster is associated with a compromise
 ##' computed by the STATIS method. Moreover, a noise cluster can be set up.
 ##'
 ##' @usage
@@ -20,9 +20,9 @@
 ##'
 ##' @param nstart integer. Number of starting partitions. Default: 100
 ##'
-##' @param rho numerical between 0 and 1. Threshold for the noise cluster. Default:0
+##' @param rho numerical or vector between 0 and 1. Threshold for the noise cluster. Default:0. If you want a different threshold for each cluster, you can provide a vector.
 ##'
-##' @param Itermax numerical. Maximum of iterations by partitionning algorithm. Default: 30
+##' @param Itermax numerical. Maximum of iterations by partitioning algorithm. Default: 30
 ##'
 ##' @param Graph_groups logical. Should each cluster compromise be plotted? Default: TRUE
 ##'
@@ -36,7 +36,7 @@
 ##' @return a list with:
 ##'         \itemize{
 ##'          \item group: the clustering partition. If rho>0, some subjects could be in the noise cluster ("K+1")
-##'          \item rho: the threshold for the noise cluster
+##'          \item rho: the threshold(s) for the noise cluster
 ##'          \item homogeneity: percentage of homogeneity of the subjects in each cluster and the overall homogeneity
 ##'          \item rv_with_compromise: RV coefficient of each subject with its cluster compromise
 ##'          \item weights: weight associated with each subject in its cluster
@@ -61,28 +61,29 @@
 ##'
 ##'
 ##' @examples
-##'data(choc)
-##'res.clu=clustatis_FreeSort_kmeans(choc, clust=2)
-##'plot(res.clu, Graph_groups=FALSE, Graph_weights=TRUE)
-##'summary(res.clu)
+##' data(choc)
+##' res.clu=clustatis_FreeSort_kmeans(choc, clust=2)
+##' plot(res.clu, Graph_groups=FALSE, Graph_weights=TRUE)
+##' summary(res.clu)
 ##'
 ##' @seealso   \code{\link{clustatis_FreeSort}}, \code{\link{preprocess_FreeSort}}, \code{\link{summary.clustatis}}, , \code{\link{plot.clustatis}}
 ##'
 ##' @export
 
 
-##=============================================================================
+## =============================================================================
 
 
-clustatis_FreeSort_kmeans=function(Data, NameSub=NULL, clust, nstart=100, rho=0,Itermax=30,
-                                   Graph_groups=TRUE, Graph_weights=FALSE,  print_attempt=FALSE)
-{
+clustatis_FreeSort_kmeans <- function(Data, NameSub = NULL, clust, nstart = 100, rho = 0,
+                                      Itermax = 30, Graph_groups = TRUE,
+                                      Graph_weights = FALSE, print_attempt = FALSE) {
+  prepro <- preprocess_FreeSort(Data, NameSub = NameSub)
 
-  prepro=preprocess_FreeSort(Data, NameSub = NameSub)
-
-  a=clustatis_kmeans(Data=prepro$new_Data, Blocks= prepro$Blocks, clust=clust, nstart=nstart,
-                     rho=rho, NameBlocks= prepro$NameBlocks, Itermax=Itermax,
-                     Graph_groups = Graph_groups, Graph_weights = Graph_weights, scale=FALSE,
-                     print_attempt = print_attempt)
+  a <- clustatis_kmeans(
+    Data = prepro$new_Data, Blocks = prepro$Blocks, clust = clust, nstart = nstart,
+    rho = rho, NameBlocks = prepro$NameBlocks, Itermax = Itermax,
+    Graph_groups = Graph_groups, Graph_weights = Graph_weights, scale = FALSE,
+    print_attempt = print_attempt
+  )
   return(a)
 }
