@@ -1,4 +1,4 @@
-##=============================================================================
+## =============================================================================
 ##' @title Print the ClusMB or clustering on STATIS axes results
 ##'
 ##' @usage
@@ -18,18 +18,16 @@
 ##' @export
 
 
-##=============================================================================
+## =============================================================================
 
-print.clusRows=function(x, ...)
-{
-  res.ClusRows=x
-  if(inherits(res.ClusRows, "clusRows")==FALSE)
-  {
+print.clusRows <- function(x, ...) {
+  res.ClusRows <- x
+  if (inherits(res.ClusRows, "clusRows") == FALSE) {
     stop("The class of the object must be 'clusRows'")
   }
 
-  cat(paste("Clustering of rows in Multi-Block context","\n" ))
-  cat(paste("number of blocks:",res.ClusRows$param$nblo, "\n"))
-  cat(paste("number of rows:",res.ClusRows$param$n, "\n"))
-  cat(paste("Method used:",res.ClusRows$type, "\n"))
+  cat(paste("Clustering of rows in Multi-Block context", "\n"))
+  cat(paste("number of blocks:", res.ClusRows$param$nblo, "\n"))
+  cat(paste("number of rows:", res.ClusRows$param$n, "\n"))
+  cat(paste("Method used:", res.ClusRows$type, "\n"))
 }
